@@ -126,7 +126,9 @@ async def video_detail(url, page):
             p = int(page[len("?p=") :])
             if p <= len(res["pages"]):
                 vurl += page + ""
-                title += f"小标题：{res['pages'][p-1]['part']}\n"
+                part = res['pages'][p-1]['part']
+                if part != res["title"]:
+                    title += f"小标题：{part}\n"
         tname = f"类型：{res['tname']} | UP：{res['owner']['name']}\n"
         stat = f"播放：{res['stat']['view']} | 弹幕：{res['stat']['danmaku']} | 收藏：{res['stat']['favorite']}\n"
         stat += f"点赞：{res['stat']['like']} | 硬币：{res['stat']['coin']} | 评论：{res['stat']['reply']}\n"
